@@ -1,4 +1,4 @@
-/*! Widget: scroller - updated 12/13/2017 (v2.29.1) *//*
+/*! Widget: scroller - updated 2018-05-07 (v2.30.4) *//*
 	Copyright (C) 2011 T. Connell & Associates, Inc.
 
 	Dual-licensed under the MIT and GPL licenses
@@ -188,7 +188,7 @@
 		},
 
 		setup : function( c, wo ) {
-			var tbHt, $hdr, $t, $hCells, $fCells, $tableWrap, events, tmp, detectedWidth,
+			var tbHt, $hdr, $t, $hCells, $tableWrap, events, tmp, detectedWidth,
 				$win = $( window ),
 				tsScroller = ts.scroller,
 				namespace = c.namespace + 'tsscroller',
@@ -203,6 +203,7 @@
 			wo.scroller_calcWidths = [];
 			wo.scroller_saved = [ 0, 0 ];
 			wo.scroller_isBusy = true;
+			wo.scroller_scrollTimer = null;
 
 			// set scrollbar width to one of the following (1) explicitly set scroller_barWidth option,
 			// (2) detected scrollbar width or (3) fallback of 15px
@@ -228,7 +229,6 @@
 					// maintain any bindings on the tfoot cells
 					.append( $t.clone( true ) )
 					.wrap( '<div class="' + tscss.scrollerFooter + '"/>' );
-				$fCells = $foot.children( 'tfoot' ).eq( 0 ).children( 'tr' ).children();
 			}
 			wo.scroller_$footer = $foot;
 
@@ -274,8 +274,11 @@
 				.off( 'scroll' + namespace )
 				.on( 'scroll' + namespace, function() {
 					// Save position
-					wo.scroller_saved[0] = $tableWrap.scrollLeft();
-					wo.scroller_saved[1] = $tableWrap.scrollTop();
+					clearTimeout(wo.scroller_scrollTimer);
+					wo.scroller_scrollTimer = setTimeout(function() {
+						wo.scroller_saved[0] = $tableWrap.scrollLeft();
+						wo.scroller_saved[1] = $tableWrap.scrollTop();
+					}, 300);
 					if ( wo.scroller_jumpToHeader ) {
 						var pos = $win.scrollTop() - $hdr.offset().top;
 						if ( $( this ).scrollTop() !== 0 && pos < tbHt && pos > 0 ) {
@@ -296,12 +299,18 @@
 
 			$table
 				.off( namespace )
+				.on( 'sortStart' + namespace, function() {
+					clearTimeout(wo.scroller_scrollTimer);
+					wo.scroller_isBusy = true;
+				})
 				.on( 'sortEnd filterEnd'.split( ' ' ).join( namespace + ' ' ), function( event ) {
 					// Sorting, so scroll to top
 					if ( event.type === 'sortEnd' && wo.scroller_upAfterSort ) {
-						$tableWrap.animate({
-							scrollTop : 0
-						}, 'fast' );
+						$tableWrap
+							.scrollLeft( wo.scroller_saved[0] )
+							.animate({ scrollTop : 0 }, 'fast', function() {
+								wo.scroller_isBusy = false;
+							});
 					} else if ( wo.scroller_fixedColumns ) {
 						setTimeout( function() {
 							// restore previous scroll position
@@ -361,7 +370,7 @@
 			// updateAll called - need to give the browser time to adjust the layout
 			// before calculating fix column widths
 			if ( c.table.hasInitialized && c.isScrolling ) {
-				setTimeout(function(){
+				setTimeout(function() {
 					ts.scroller.resize( c, wo );
 				}, 50);
 			}
@@ -745,12 +754,18 @@
 				tsScroller = ts.scroller,
 				fixedColumns = wo.scroller_fixedColumns,
 				// get dimensions
+				getDim = function ($el, name, deflt) {
+					return parseInt( $el.css(name) || '', 10 ) || deflt || 0;
+				},
 				$temp = $table.find( 'tbody td' ),
-				borderRightWidth = parseInt( $temp.css( 'border-right-width' ), 10 ) || 1,
-				borderSpacing = parseInt( ( $temp.css( 'border-spacing' ) || '' ).split( /\s/ )[ 0 ], 10 ) / 2 || 0,
-				totalWidth = parseInt( $table.css( 'padding-left' ), 10 ) +
-					parseInt( $table.css( 'padding-right' ), 10 ) -
-					borderRightWidth,
+				borderRightWidth = getDim( $temp, 'border-right-width', 1 ),
+				borderSpacing = getDim( $temp, 'border-spacing', 0 ),
+				totalWidth = getDim( $table, 'padding-left' ) +
+					getDim( $table, 'padding-right' ) +
+					// include table left & row left border
+					getDim( $table, 'border-left-width', 1 ) * 2 +
+					getDim( $table, 'border-right-width', 1 ) -
+					borderRightWidth + borderSpacing / 2,
 				widths = wo.scroller_calcWidths;
 
 			ts.scroller.removeFixed( c, wo, false );
@@ -761,7 +776,7 @@
 			}
 
 			// set fixed column width
-			totalWidth = totalWidth + borderRightWidth * 2 - borderSpacing;
+			totalWidth = totalWidth + borderRightWidth * 2;
 			tsScroller.setWidth( $fixedColumn.add( $fixedColumn.children() ), totalWidth );
 			tsScroller.setWidth( $fixedColumn.children().children( 'table' ), totalWidth );
 
@@ -799,7 +814,6 @@
 					.css( 'width', totalWidth + adj );
 			}
 
-			$fixedColumn.removeClass( tscss.scrollerHideElement );
 			for ( index = 0; index < fixedColumns; index++ ) {
 				temp = ':nth-child(' + ( index + 1 ) + ')';
 				$wrapper
@@ -808,6 +822,14 @@
 					.find( 'th' + temp + ', td' + temp + ', col' + temp )
 					.addClass( tscss.scrollerHideColumn );
 			}
+			$fixedColumn
+				.removeClass( tscss.scrollerHideElement )
+				.find('colgroup')
+				.each(function() {
+					$(this)
+						.find('col:gt(' + (fixedColumns - 1) + ')')
+						.addClass( tscss.scrollerHideElement );
+				});
 
 			totalWidth = totalWidth - borderRightWidth;
 			temp = $tableWrap.parent().innerWidth() - totalWidth;
@@ -847,7 +869,9 @@
 			$fixedColumn.find('caption').height( wo.scroller_$header.find( 'caption' ).height() );
 
 			$tableWrap.scroll();
-			wo.scroller_isBusy = false;
+			setTimeout(function() {
+				wo.scroller_isBusy = false;
+			}, 0)
 
 		},
 
